import { ShareAddress } from "../util/doc-types.js";
import { IPeer } from "./peer-types.js";
import { Replica } from "../replica/replica.js";
import { Syncer } from "../syncer/syncer.js";
import { FormatsArg } from "../formats/format_types.js";
import { ISyncPartner } from "../syncer/syncer_types.js";
/** Holds many shares' replicas and manages their synchronisation with other peers. Recommended as the point of contact between your application and Earthstar shares. */
export declare class Peer implements IPeer {
    private replicaEventBus;
    private syncerManager;
    /** A map of the replicas stored in this peer. */
    replicaMap: Map<ShareAddress, Replica>;
    constructor();
    hasShare(share: ShareAddress): boolean;
    shares(): ShareAddress[];
    replicas(): Replica[];
    /** The number of replicas held by this peer */
    size(): number;
    getReplica(ws: ShareAddress): Replica | undefined;
    addReplica(replica: Replica): Promise<void>;
    removeReplicaByShare(share: ShareAddress): Promise<void>;
    removeReplica(replica: Replica): Promise<void>;
    /**
     * Begin synchronising with a remote or local peer.
     * @param target - A HTTP URL or `Peer` instance.
     * @param continuous - Whether the connection should be kept open for newly written docs, or stop after an initial sync.
     * @param formats - Optional. Which document formats to sync. Defaults to `es.5`.
     */
    sync<F>(target: IPeer | string, continuous?: boolean, formats?: FormatsArg<F>): Syncer<undefined, F>;
    /** Begin syncing using an instance implementing `ISyncPartner`. Use this if you don't want to sync with a local peer or a replica server. */
    addSyncPartner<I, F>(partner: ISyncPartner<I>, description: string, formats?: FormatsArg<F>): Syncer<I, F>;
    /** Get all syncers created by this peer. This includes running and cancelled syncers. */
    getSyncers(): Map<string, {
        description: string;
        syncer: Syncer<unknown, unknown>;
    }>;
    /** Fires a given callback whenever the Peer's store of replicas changes. */
    onReplicasChange(callback: (map: Map<ShareAddress, Replica>) => void | Promise<void>): () => void;
    /** Fires a given callback whenever a new syncer is added to the peer. */
    onSyncersChange(callback: (map: Map<string, {
        description: string;
        syncer: Syncer<unknown, unknown>;
    }>) => void | Promise<void>): () => void;
}
