import { AuthorKeypair } from "../crypto/crypto-types.js";
import { ShareAddress } from "./doc-types.js";
import { ValidationError } from "./errors.js";
import { Replica } from "../replica/replica.js";
import { Peer } from "../peer/peer.js";
declare type ClientSettingsOpts = {
    /** A namespace to restrict these settings to. */
    namespace?: string;
    /** Whether to use session storage for these settings. */
    sessionOnly?: true;
};
export declare class ClientSettings {
    private namespace;
    private storage;
    constructor(opts?: ClientSettingsOpts);
    get author(): AuthorKeypair | null;
    set author(keypair: AuthorKeypair | null);
    get shares(): ShareAddress[];
    addShare(address: ShareAddress): ValidationError | string[];
    removeShare(addressToRemove: string): ValidationError | string[];
    get shareSecrets(): Record<string, string>;
    addSecret(shareAddress: ShareAddress, secret: string): Promise<ValidationError | {
        [x: string]: string;
    }>;
    removeSecret(shareAddress: ShareAddress): ValidationError | {
        [x: string]: string;
    };
    get servers(): string[];
    addServer(address: string): string[] | ValidationError;
    removeServer(addressToRemove: string): ValidationError | string[];
    clear(): void;
    private authorChangedCbs;
    onAuthorChanged(cb: (keypair: AuthorKeypair | null) => void): () => void;
    private sharesChangedCbs;
    onSharesChanged(cb: (shares: ShareAddress[]) => void): () => void;
    private shareSecretsChangedCbs;
    onShareSecretsChanged(cb: (secrets: Record<ShareAddress, string>) => void): () => void;
    private serversChangedCbs;
    onServersChanged(cb: (shares: string[]) => void): () => void;
    /** Get a new `Peer` preconfigured with shares, secrets, and syncers derived from these settings.
     *
     * When settings are updated, the peer's replicas and syncers will be updated too.
     */
    getPeer({ sync, onCreateReplica }: {
        /** Whether to start syncing using the settings' servers. */
        sync: "once" | "continuous" | false;
        /** Used to create replicas when a new share is added to settings. */
        onCreateReplica: (addr: ShareAddress, secret?: string) => Replica;
    }): {
        /** A preconfigured Peer. */
        peer: Peer;
        /** Stop changes to ClientSettings from propagating to the Peer. */
        unsubscribeFromSettings: () => void;
    };
    private fireAuthorEvent;
    private fireSharesEvent;
    private fireSecretsEvent;
    private fireServersEvent;
}
export {};
