import * as dntShim from "../../_dnt.shims.js";
import { ValidationError } from "./errors.js";
/** An identity's public address. */
export declare type AuthorAddress = string;
/** The human-identifiable portion of an identity's public address, e.g. `suzy`. */
export declare type AuthorShortname = string;
/** A share's public address. */
export declare type ShareAddress = string;
/** The human-identifiable portion of a share's address, e.g. `gardening`. */
export declare type ShareName = string;
/** The path of a document, e.g. `/images/teapot.png`. */
export declare type Path = string;
export declare type Signature = string;
/** A UNIX timestamp in microseconds. */
export declare type Timestamp = number;
export declare type LocalIndex = number;
export declare type Base32String = string;
export declare type FormatName = string;
export declare type ParsedAddress = {
    address: AuthorAddress;
    name: AuthorShortname;
    pubkey: Base32String;
};
/** The core properties all documents must implement, regardless of format. */
export interface DocBase<FormatType extends string> {
    format: FormatType;
    path: string;
    author: AuthorAddress;
    timestamp: Timestamp;
    signature: Signature;
    deleteAfter?: number | null;
    _localIndex?: number;
}
export interface DocInputBase<FormatType extends string> {
    format: FormatType;
    path: string;
    timestamp?: Timestamp;
}
export declare type DocWithFormat<FormatType extends string, DocType extends DocBase<string>> = Extract<DocType, {
    "format": FormatType;
}>;
export declare type DocInputWithFormat<FormatType extends string, DocInputType extends DocInputBase<string>> = Extract<DocInputType, {
    "format": FormatType;
}>;
/** An attachment associated with a document. */
export declare type DocAttachment = {
    /** Returns a stream to use the attachment's bytes chunk by chunk. Useful if the attachment is very big. */
    stream: () => Promise<dntShim.ReadableStream<Uint8Array>>;
    /** Returns all of the attachments bytes in one go. Handier if you know the attachment is small. */
    bytes: () => Promise<Uint8Array>;
};
/** A document with it's attachment merged onto a new `attachment` property. */
export declare type DocWithAttachment<D extends DocBase<string>> = D & {
    attachment: DocAttachment | undefined | ValidationError;
};
